==> qtjambi-multimedia-debuginfo-linux-x64-6.5.7.jar: sources/QtJambiMultimedia/QMediaRecorder_shell.h <==
#ifndef QMEDIARECORDER_SHELL_H
#define QMEDIARECORDER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED
QT_WARNING_DISABLE_GCC("-Wdeprecated-declarations")

#include <QtMultimedia/qmediarecorder.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qurl.h>
#include <QtMultimedia/qmediacapturesession.h>
#include <QtMultimedia/qmediaformat.h>
#include <QtMultimedia/qmediametadata.h>
#include "utils_p.h"
#include <QtJambi/RegistryAPI>


class QMediaRecorder_shell : public QMediaRecorder, public QtJambiShellInterface
{
public:
    QMediaRecorder_shell(QObject* parent0 = nullptr);
    ~QMediaRecorder_shell() override;
    static void operator delete(void * ptr) noexcept;
private:
    QtJambiShell* __shell() const override final;
    friend class QMediaRecorder_mshell;
    friend class QMediaRecorder_oshell;
};


class QMediaRecorder_mshell : public QMediaRecorder_shell
{
public:
    using QMediaRecorder_shell::QMediaRecorder_shell;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
};


class QMediaRecorder_oshell : public QMediaRecorder_mshell
{
public:
    using QMediaRecorder_mshell::QMediaRecorder_mshell;
    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
private:
    jmethodID __shell_javaMethod(int pos) const;
};

struct QMediaRecorder_access : public QMediaRecorder
{
};

#endif // QMEDIARECORDER_SHELL_H

==> qtjambi-multimedia-debuginfo-linux-x64-6.6.0.jar: sources/QtJambiMultimedia/QMediaRecorder_shell.h <==
#ifndef QMEDIARECORDER_SHELL_H
#define QMEDIARECORDER_SHELL_H

#include <QtCore/QtGlobal>
#include <QtCore/qcompilerdetection.h>

QT_WARNING_DISABLE_DEPRECATED

#include <QtMultimedia/qmediarecorder.h>
#include <QtJambi/QtJambiAPI>
#include <QtCore/QList>
#include <QtCore/QVariant>
#include <QtCore/qbindingstorage.h>
#include <QtCore/qbytearray.h>
#include <QtCore/qcoreevent.h>
#include <QtCore/qmetaobject.h>
#include <QtCore/qnamespace.h>
#include <QtCore/qobject.h>
#include <QtCore/qproperty.h>
#include <qtcore-config.h>
#if QT_CONFIG(regularexpression)
#include <QtCore/qregularexpression.h>
#endif //QT_CONFIG(regularexpression)
#include <QtCore/qsize.h>
#include <QtCore/qthread.h>
#include <QtCore/qtimer.h>
#include <QtCore/qurl.h>
#include <QtCore/qvariant.h>
#include <QtMultimedia/qmediacapturesession.h>
#include <QtMultimedia/qmediaformat.h>
#include <QtMultimedia/qmediametadata.h>
#include "utils_p.h"
#include <QtJambi/RegistryAPI>


class QMediaRecorder_shell : public QMediaRecorder, public QtJambiShellInterface
{
public:
    QMediaRecorder_shell(QObject* parent0 = nullptr);
    ~QMediaRecorder_shell() override;

    void childEvent(QChildEvent* event0) override;
    void connectNotify(const QMetaMethod& signal0) override;
    void customEvent(QEvent* event0) override;
    void disconnectNotify(const QMetaMethod& signal0) override;
    bool event(QEvent* event0) override;
    bool eventFilter(QObject* watched0, QEvent* event1) override;
    void timerEvent(QTimerEvent* event0) override;
    static void operator delete(void * ptr) noexcept;
    const QMetaObject *metaObject() const override final;
    void *qt_metacast(const char *) override final;
    int qt_metacall(QMetaObject::Call, int, void **) override final;
private:
    QtJambiShell* __shell() const override final;
    jmethodID __shell_javaMethod(int pos) const;
};

struct QMediaRecorder_access : public QMediaRecorder
{
};

#endif // QMEDIARECORDER_SHELL_H
